@@ -26,7 +26,7 @@
  * SUCH DAMAGE.
  */
 /*
- * $Id: mgp.h,v 1.140 2004/09/07 16:57:42 nishida Exp $
+ * $Id: mgp.h,v 1.146 2008/01/18 17:43:20 nishida Exp $
  */
 
 #include <stdio.h>
@@ -107,7 +107,6 @@
 #ifdef USE_M17N
 #include <m17n-gui.h>
 #include <m17n-misc.h>
-#include <m17n-X.h>
 #endif
 
 #define DEFAULT_FORE	"yellow"
@@ -127,7 +126,7 @@
 #define XLFD_HYPHEN	14
 #define FONT_FORMAT	"-*-%s-*-*-%s-*-*-*-*-*-%s"
 #define DEFAULT_X_FONT	"times-medium-r"
-#define CUTIN_DELAY	15000
+#define CUTIN_DELAY	5000
 #define SHRINK_DELAY	00500
 #define EXEC_DELAY  20000
 
@@ -246,6 +245,8 @@ struct ctrl_image {
 	u_int ct_yimagesize;
 	u_int ct_zoomflag;
 	u_int ct_raise;
+	u_int ct_rotate; /* +/-180, +/-90, 0, 270 */
+	u_int ct_zoomonclk; 
 #define Z_XMASK		0x0f
 #define Z_YMASK		0xf0
 #define Z_YSHIFT	4
@@ -344,6 +345,8 @@ struct ctrl {
 #define ctm_yimagesize	ct_val.ctrl_image.ct_yimagesize
 #define ctm_zoomflag	ct_val.ctrl_image.ct_zoomflag
 #define ctm_raise	ct_val.ctrl_image.ct_raise
+#define ctm_rotate	ct_val.ctrl_image.ct_rotate
+#define ctm_zoomonclk	ct_val.ctrl_image.ct_zoomonclk
 #define ctd_colors	ct_val.ctrl_grad.colors
 #define ctd_g_colors	ct_val.ctrl_grad.ct_g_colors
 #define ctd_numcolor	ct_val.ctrl_grad.ct_numcolor
@@ -502,6 +505,10 @@ struct render_object {
 		struct {
 			Image *image;
 			float xzoom, yzoom;
+#ifdef USE_IMLIB
+			int zoomonclk;
+			ImlibImage *imimage;
+#endif
 		} image;
 		struct {
 			u_int itype;
@@ -531,7 +538,7 @@ struct render_object {
 		struct {
 			MText *mt;
 			MFrame *drawframe;
-			int len;
+			int from, to;
 		} m17ntext;
 #endif
 	} data;
@@ -735,6 +742,14 @@ extern Bool draw_one __P((struct render_state *, XEvent *));
 extern void timebar __P((struct render_state *));
 extern void draw_reinit __P((struct render_state *));
 extern int get_regid __P((char *));
+extern void draw_line_itemsize __P((struct render_state *, int, int, int));
+extern void draw_line_start __P((struct render_state *));
+extern void draw_line_end __P ((struct render_state *));
+
+#ifdef USE_M17N
+extern int obj_new_mtext __P((struct render_state *, int, int,
+			      MText *, int, int, MFrame *, int, int));
+#endif
 
 /*parse.c*/
 extern void load_file __P((char *));
@@ -829,12 +844,12 @@ extern void usleep __P((u_int));
 #endif
 
 #ifdef USE_M17N
-void M17N_init __P((void));
-void M17N_set_size __P((int));
-void M17N_set_color __P((u_long));
-MText * M17N_gen_mtext __P((u_char *));
-void M17N_process_direc __P((char *, char *));
-void M17N_draw_string __P((struct render_state *, char *));
-char * M17N_draw_fragment __P((struct render_state *, u_char *, u_int));
-void M17N_draw_object __P((struct render_object *, Drawable, int, int));
+/*m17n.c*/
+extern void M17N_init __P((void));
+extern void M17N_fini __P((void));
+extern void M17N_set_font __P((char *, char *));
+extern void M17N_set_color __P((u_long));
+extern void M17N_process_direc __P((char *, char *));
+extern void M17N_draw_string __P((struct render_state *, struct ctrl *cp));
+extern void M17N_draw_object __P((struct render_object *, Drawable, int, int));
 #endif
